@@ -10,11 +10,15 @@ from solana.sysvar import SYSVAR_RENT_PUBKEY
 from solana.transaction import AccountMeta
 from spl.token.constants import TOKEN_PROGRAM_ID
 from anchorpy import Program, Context, Idl
-from driftpy.addresses import get_user_account_public_key_and_nonce
+from driftpy.addresses import (
+    get_user_account_public_key_and_nonce,
+    get_user_orders_account_public_key_and_nonce,
+)
 from driftpy.types import (
     PositionDirection,
     StateAccount,
     MarketsAccount,
+    Market,
     FundingPaymentHistoryAccount,
     FundingRateHistoryAccount,
     TradeHistoryAccount,
@@ -93,6 +97,10 @@ class ClearingHouse:
         res = await self.program.account["Markets"].fetch(self.pdas.markets)
         return cast(MarketsAccount, res)
 
+    async def get_market(self, market_index) -> Market:
+        market = (await self.get_markets_account()).markets[market_index]
+        return cast(Market, market)
+
     async def get_funding_payment_history_account(self) -> FundingPaymentHistoryAccount:
         res = await self.program.account["FundingPaymentHistory"].fetch(
             self.pdas.funding_payment_history
@@ -291,6 +299,15 @@ class ClearingHouse:
             self.program.program_id, self.program.provider.wallet.public_key
         )[0]
 
+    def get_user_orders_public_key(self) -> PublicKey:
+        """Get the address for the Clearing House User's order account.
+
+        NOT the user's wallet address.
+        """
+        return get_user_orders_account_public_key_and_nonce(
+            self.program.program_id, self.program.provider.wallet.public_key
+        )[0]
+
     async def get_withdraw_collateral_ix(
         self,
         amount: int,
